[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - pytilities.test.attributecollection.A
    - pytilities.test.attributecollection.B
      - pytilities.test.attributecollection.D
  - pytilities.test.overloading.overloaded.A: Some class to test with
  - pytilities.test.delegation.delegation.A
  - pytilities.attributecollection.AttributeCollection: Abstract, represents a collection of attributes.
    - pytilities.delegation.delegator.Delegator: An AttributeCollection that delegates attributes of one object to another.
  - pytilities.attributecollectionbase.AttributeCollectionBase: Mixin, allows extension of instance attributes with `AttributeCollection`s
    - pytilities.test.event.decorators.ADispatcher
      - pytilities.test.event.decorators.BDispatcher
    - pytilities.test.attributecollection.B
      - pytilities.test.attributecollection.D
    - pytilities.test.delegation.delegation.Default
    - pytilities.geometry.immutablevector.ImmutableVector: Vector wrapper that makes the vector immutable.
    - pytilities.test.delegation.delegation.Public
    - pytilities.test.event.decorators.Switch
      - pytilities.test.event.decorators.BSwitch
    - pytilities.geometry.verboserectangle.VerboseRectangle: A Rectangle wrapper that sends out events
    - pytilities.geometry.verbosevector.VerboseVector: Vector wrapper that sends out events.
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - exceptions.AssertionError: Assertion failed.
      - pytilities.event.dispatcher_.UnsupportedEventError: Tried to access an unregistered event
  - pytilities.test.attributecollection.C
    - pytilities.test.attributecollection.D
  - pytilities.delegation.delegatorfactory.DelegatorFactory: Allows easy creation of delegators with `Profile`s.
  - pytilities.event.dispatcher_.Dispatcher: Utility class for dispatching events to handlers.
  - pytilities.event.dispatcherswitch.DispatcherSwitch: Provides a single interface to multiple event dispatchers.
  - pytilities.test.event.helpers.Listener
  - pytilities.types.numbertype.NumberType: Represents any number type.
  - pytilities.types.numerictype.NumericType: Represents any numeric type.
  - pytilities.overloading.overload.Overload: A list of parameters that when matched, call an associated operation.
  - pytilities.overloading.overloader.Overloader: A collection of `Overload`s that can process calls.
  - pytilities.overloading.parameter.Parameter: A parameter of an operation.
    - pytilities.overloading.compositeparameter.CompositeParameter: Parameter that consists of more parameters.
  - pytilities.delegation.profile.Profile: States what attributes to delegate, and to which target attributes.
  - pytilities.geometry.rectangle.Rectangle: A rectangle identified by two points.
  - pytilities.event.restricteddispatcher.RestrictedDispatcher: Dispatcher wrapper that filters the list of supported events.
  - pytilities.types.sequencetype.SequenceType: Represents any ordered sequence.
  - pytilities.test.overloading.overloaded.Storage: Something with an x and y
  - pytilities.stringifiable.Stringifiable: Mixin that provides a reasonable default __str__.
  - unittest.TestCase: A class whose instances are single test cases.
    - pytilities.test.event.restricteddispatcher.AllowTestCase: Using the allow arg
    - pytilities.test.overloading.parameter.ArgMissingTestCase
    - pytilities.test.overloading.parameter.ArgPresentTestCase
    - pytilities.test.event.decorators.BSwitchTestCase
    - pytilities.test.overloading.parameter.CtorTestCase
    - pytilities.test.event.restricteddispatcher.DisallowTestCase: Using the disallow arg
    - pytilities.test.event.decorators.DispatcherTestCase
      - pytilities.test.event.decorators.BDispatcherTestCase
    - pytilities.test.attributecollection.DisturbanceTestCase: Test whether or not basic inheritance is left unharmed by AttributeCollectionBase
    - pytilities.test.geometry.vector.DoubleBoundVectorTestCase
    - pytilities.test.overloading.overloaded.FunctionTestCase: Test overloading of a function
    - pytilities.test.event.dispatcher.InitTestCase
    - pytilities.test.event.dispatcherswitch.InitTestCase
    - pytilities.test.mangling.MainTestCase
    - pytilities.test.delegation.delegation.MainTestCase
    - pytilities.test.delegation.profile.MainTestCase
    - pytilities.test.overloading.overloaded.MethodTestCase: Test overloading of a method
    - pytilities.test.geometry.rectangle.RectangleCtorTestCase
    - pytilities.test.geometry.rectangle.RectangleTestCase
      - pytilities.test.geometry.rectangle.VerboseRectangleTestCase
    - pytilities.test.event.decorators.SwitchTestCase
    - pytilities.test.geometry.vector.VectorTestCase
      - pytilities.test.geometry.vector.BoundVectorTestCase
      - pytilities.test.geometry.vector.ImmutableVectorTestCase
      - pytilities.test.geometry.vector.VerboseVectorTestCase
  - pytilities.test.mangling.Testlet
  - pytilities.test.geometry.vector.VHolder
  - pytilities.geometry.vector.Vector: 2D Point/Vector
    - pytilities.geometry.boundvector.BoundVector: Vector whose x and y values are stored elsewhere.
  - pytilities.geometry.boundvector._DelegatedStorage
  - pytilities.geometry.vector._Storage
  - type: type(object) -> the object's type type(name, bases, dict) -> a new type
    - pytilities.types._numbertypemeta._NumberTypeMeta
    - pytilities.types._numerictypemeta._NumericTypeMeta
    - pytilities.types._sequencetypemeta._SequenceTypeMeta